@@ -1,5 +1,6 @@
 import tomlkit
 from tomlkit.toml_document import TOMLDocument
+from typing import Dict, List
 
 
 def extract_top_namespace(include: str) -> str:
@@ -8,18 +9,18 @@ def extract_top_namespace(include: str) -> str:
     return next(parts)
 
 
-def is_relative(package: dict[str, str]) -> bool:
+def is_relative(package: Dict[str, str]) -> bool:
     return "from" in package and ".." in package.get("from", "")
 
 
-def relative_to_local(packages) -> list[dict[str, str]]:
+def relative_to_local(packages) -> List[Dict[str, str]]:
     relative = [p for p in packages if is_relative(p)]
     includes = {extract_top_namespace(p["include"]) for p in relative}
 
     return [{"include": i} for i in includes]
 
 
-def to_valid_dist_packages(data: TOMLDocument) -> list[dict[str, str]]:
+def to_valid_dist_packages(data: TOMLDocument) -> List[Dict[str, str]]:
     packages = data["tool"]["poetry"]["packages"]
 
     local = [p for p in packages if not is_relative(p)]
